summaryrefslogtreecommitdiffstats
path: root/windows.c
diff options
context:
space:
mode:
Diffstat (limited to 'windows.c')
-rw-r--r--windows.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/windows.c b/windows.c
index a9031d6..bf00f81 100644
--- a/windows.c
+++ b/windows.c
@@ -331,10 +331,10 @@ int window_flush(struct mbox_context *context, uint32_t offset,
/* Window Management Functions */
/*
* alloc_window_dirty_bytemap() - (re)allocate all the window dirty bytemaps
* @context: The mbox context pointer
*/
-void alloc_window_dirty_bytemap(struct mbox_context *context)
+void windows_alloc_dirty_bytemap(struct mbox_context *context)
{
struct window_context *cur;
int i;
@@ -331,10 +331,10 @@ int window_flush(struct mbox_context *context, uint32_t offset,
/* Window Management Functions */
/*
- * alloc_window_dirty_bytemap() - (re)allocate all the window dirty bytemaps
+ * windows_alloc_dirty_bytemap() - (re)allocate all the window dirty bytemaps
* @context: The mbox context pointer
*/
OpenPOWER on IntegriCloud